from setuptools import setup

setup(name='oops_package',
      version='0.0',
      description='Set Operations(Union, Intersection,Minus)',
      packages=['oops_package'],
      author_email='raghavshetty319@gmail.com',
      zip_safe=False)
